@@ -1,5 +1,4 @@
-use strict;
-use warnings;
+use strictures 2;
 
 package Dist::Zilla::PluginBundle::ZURBORG;
 
@@ -7,7 +6,7 @@ package Dist::Zilla::PluginBundle::ZURBORG;
 
 use Moose;
 
-our $VERSION = '0.003';    # VERSION
+our $VERSION = '0.004';    # VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -56,6 +55,7 @@ sub configure {
         [ 'MetaYAML'            => {} ],
         [ 'License'             => {} ],
         [ 'Readme'              => {} ],
+        [ 'CPANFile'            => {} ],
         [ 'ExtraTests'          => {} ],
         [ 'PodSyntaxTests'      => {} ],
         [ 'PodCoverageTests'    => {} ],
@@ -92,7 +92,7 @@ Dist::Zilla::PluginBundle::ZURBORG - dzil plugin bundle of ZURBORG
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 METHODS
 
